/*
    (C) 1995-97 AROS - The Amiga Research OS
    $Id: setprogramname.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc: Sets the name of the current program.
    Lang: English
*/
#include <proto/exec.h>
#include <proto/dos.h>
#include <dos/dos.h>
#include <dos/dosextens.h>
#include "dos_intern.h"

/*****************************************************************************

    NAME */

#include <proto/dos.h>

	AROS_LH1(LONG, SetProgramName,

/*  SYNOPSIS */
	AROS_LHA(STRPTR, name, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 95, Dos)

/*  FUNCTION
	Sets the name for the current program in the CLI structure. If the
	name doesn't fit the old name is kept and a failure is returned.
	If the current process doesn't have a CLI structure this function
	does nothing.

    INPUTS
	name  --  Name for the current program.

    RESULT
	!= 0 on success, 0 on failure.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	GetProgramName()

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    FAILFORTASKNP(return DOSFALSE;)

    return internal_SetProgramName(Cli(), (CONST_STRPTR) name, DOSBase) ? DOSTRUE : DOSFALSE;

    AROS_LIBFUNC_EXIT
} /* SetProgramName */


LONG internal_SetProgramName(struct CommandLineInterface *cli, CONST_STRPTR name, struct DosLibrary *DOSBase)
{
    STRPTR  s;
    ULONG   namelen;

    if (cli == NULL)
	return DOSFALSE;

    s = (STRPTR) name;
    while(*s++)
	;
    namelen = s - name - 1;

    if (namelen > (CLI_COMMNAME_MAX - 2))
	namelen = CLI_COMMNAME_MAX - 2;

    s = AROS_BSTR_ADDR(cli->cli_CommandName);

    AROS_BSTR_setstrlen(cli->cli_CommandName, namelen);
    CopyMem((APTR)name, s, namelen);
    s[namelen] = '\0';

    return DOSTRUE;
}
